==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/msk_cluster/MskClusterBrokerNodeGroupInfoStorageInfo.java <==
package com.hashicorp.cdktf.providers.aws.msk_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.791Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfoStorageInfo")
@software.amazon.jsii.Jsii.Proxy(MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskClusterBrokerNodeGroupInfoStorageInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * ebs_storage_info block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#ebs_storage_info MskCluster#ebs_storage_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo getEbsStorageInfo() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskClusterBrokerNodeGroupInfoStorageInfo> {
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo;

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfoStorageInfo#getEbsStorageInfo}
         * @param ebsStorageInfo ebs_storage_info block.
         *                       Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/msk_cluster#ebs_storage_info MskCluster#ebs_storage_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ebsStorageInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo) {
            this.ebsStorageInfo = ebsStorageInfo;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskClusterBrokerNodeGroupInfoStorageInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskClusterBrokerNodeGroupInfoStorageInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskClusterBrokerNodeGroupInfoStorageInfo {
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ebsStorageInfo = software.amazon.jsii.Kernel.get(this, "ebsStorageInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ebsStorageInfo = builder.ebsStorageInfo;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo getEbsStorageInfo() {
            return this.ebsStorageInfo;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEbsStorageInfo() != null) {
                data.set("ebsStorageInfo", om.valueToTree(this.getEbsStorageInfo()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfoStorageInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy that = (MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy) o;

            return this.ebsStorageInfo != null ? this.ebsStorageInfo.equals(that.ebsStorageInfo) : that.ebsStorageInfo == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ebsStorageInfo != null ? this.ebsStorageInfo.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/msk_cluster/MskClusterBrokerNodeGroupInfoStorageInfo.java <==
package com.hashicorp.cdktf.providers.aws.msk_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.804Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfoStorageInfo")
@software.amazon.jsii.Jsii.Proxy(MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MskClusterBrokerNodeGroupInfoStorageInfo extends software.amazon.jsii.JsiiSerializable {

    /**
     * ebs_storage_info block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#ebs_storage_info MskCluster#ebs_storage_info}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo getEbsStorageInfo() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MskClusterBrokerNodeGroupInfoStorageInfo> {
        com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo;

        /**
         * Sets the value of {@link MskClusterBrokerNodeGroupInfoStorageInfo#getEbsStorageInfo}
         * @param ebsStorageInfo ebs_storage_info block.
         *                       Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/msk_cluster#ebs_storage_info MskCluster#ebs_storage_info}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder ebsStorageInfo(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo) {
            this.ebsStorageInfo = ebsStorageInfo;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MskClusterBrokerNodeGroupInfoStorageInfo}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MskClusterBrokerNodeGroupInfoStorageInfo build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MskClusterBrokerNodeGroupInfoStorageInfo}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MskClusterBrokerNodeGroupInfoStorageInfo {
        private final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo ebsStorageInfo;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.ebsStorageInfo = software.amazon.jsii.Kernel.get(this, "ebsStorageInfo", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.ebsStorageInfo = builder.ebsStorageInfo;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.msk_cluster.MskClusterBrokerNodeGroupInfoStorageInfoEbsStorageInfo getEbsStorageInfo() {
            return this.ebsStorageInfo;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getEbsStorageInfo() != null) {
                data.set("ebsStorageInfo", om.valueToTree(this.getEbsStorageInfo()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.mskCluster.MskClusterBrokerNodeGroupInfoStorageInfo"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy that = (MskClusterBrokerNodeGroupInfoStorageInfo.Jsii$Proxy) o;

            return this.ebsStorageInfo != null ? this.ebsStorageInfo.equals(that.ebsStorageInfo) : that.ebsStorageInfo == null;
        }

        @Override
        public final int hashCode() {
            int result = this.ebsStorageInfo != null ? this.ebsStorageInfo.hashCode() : 0;
            return result;
        }
    }
}
